@@ -3,11 +3,10 @@ use strict;
 use warnings;
 
 package BSON::Binary;
-# ABSTRACT: Binary data for BSON
+# ABSTRACT: Legacy BSON type wrapper for binary data (DEPRECATED)
 
-our $VERSION = '0.16';
-
-use overload '""' => \&to_s;
+use version;
+our $VERSION = 'v1.0.0';
 
 our $TYPE_SIMPLE       = 0x00;
 our $TYPE_BYTES        = 0x02;
@@ -36,15 +35,20 @@ sub type {
     return $_[0]->{type};
 }
 
+# alias for compatibility with BSON::Bytes
+sub subtype {
+    return $_[0]->{type};
+}
+
 sub to_s {
     my $self = shift;
     my @data = @{ $self->data };
     return pack( 'lC*', scalar(@data), $self->type, @data );
 }
 
-1;
+use overload '""' => \&to_s;
 
-__END__
+1;
 
 =pod
 
@@ -52,55 +56,22 @@ __END__
 
 =head1 NAME
 
-BSON::Binary - Binary data for BSON
+BSON::Binary - Legacy BSON type wrapper for binary data (DEPRECATED)
 
 =head1 VERSION
 
-version 0.16
-
-=head1 SYNOPSIS
-
-    use BSON;
-
-    my $bin = BSON::Binary->new([1,2,3,4,5,0x67,0x89], 0);
+version v1.0.0
 
 =head1 DESCRIPTION
 
-This module is needed for L<BSON> and it manages BSON's binary element.
+This module has been deprecated as it was horribly inefficient (unpacking
+binary data to individual single-byte elements of an array!) and had a
+weird API that was not compatible with the existing MongoDB Binary wrapper
+implementation on CPAN.
 
-=for Pod::Coverage to_s
+You are strongly encouraged to use L<BSON::Bytes> instead.
 
-=head1 METHODS
-
-=head2 new
-
-Main constructor which takes two parameters: An array reference with 
-binary data and a data type. A string may also be passed as the first parameter, 
-in which case it will be converted to an array ref.
-
-    my $bin = BSON::Binary->new("classic\x20string\0", 0);
-
-The different types are described in the BSON specification. A type is
-one of the following:
-
-    0x00  Binary / Generic
-    0x01  Function
-    0x02  Binary (Old)
-    0x03  UUID
-    0x05  MD5
-    0x80  User defined
-
-=head2 data
-
-Returns an array reference to the contents of the binary data.
-
-=head2 type
-
-Returns the type of the binary data per the BSON specification.
-
-=head1 SEE ALSO
-
-L<BSON>
+=for Pod::Coverage new data type subtype to_s
 
 =head1 AUTHORS
 
@@ -108,20 +79,25 @@ L<BSON>
 
 =item *
 
-minimalist <minimalist@lavabit.com>
+David Golden <david@mongodb.com>
 
 =item *
 
-David Golden <david@mongodb.com>
+Stefan G. <minimalist@lavabit.com>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by minimalist and MongoDB, Inc..
+This software is Copyright (c) 2016 by Stefan G. and MongoDB, Inc.
 
 This is free software, licensed under:
 
   The Apache License, Version 2.0, January 2004
 
 =cut
+
+__END__
+
+
+# vim: set ts=4 sts=4 sw=4 et tw=75:
